@@ -1,4 +1,3 @@
-# -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
 # Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
@@ -19,21 +18,19 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
-'''
+"""
 Phone communication libary - python wrapper for Gammu library.
-'''
+"""
 
 from gammu._gammu import *
 
-__version__ = 'Gammu {0}, python-gammu {1}'.format(
-    *Version()
-)
+__version__ = "Gammu {}, python-gammu {}".format(*Version())
 
 # Submodules
 __all__ = [
-    'data',
-    'worker',
-    'asyncworker',
-    'smsd',
-    'exception',
+    "data",
+    "worker",
+    "asyncworker",
+    "smsd",
+    "exception",
 ]
